Author: Vincent J. Matsko
Date: 18 October 2015, Day009
Post: Creating Fractals III:  Making Your Own
︠7aa6e844-1613-4d19-a8c5-7bbfdc41d4cc︠
# Again, remember shift+enter to evaluate!

from sage.plot.colors import rgbcolor

# Makes sure r is in the correct range (that is, between 0 and 1).
# You might add or subtract to an RGB value and inadvertantly go outside the range [0,1]. 
def RGBValue (r): 
    if r < 0:
        return 0
    else:
        if r > 1:
            return 1
        else:
            return r

# Note that this routine adds the delta to the colors.  You can subtract, too.
def RandomColor(base, delta):
    return rgbcolor([RGBValue(base[count] + delta * random()) for count in range(3)])

# As arguments, provide the width, height, color (RGB values), delta (change in the color parameters), and the random number seed.
def ColorSquare(width, height, color, delta, seed):
    squares = []  # Saves the points in the final image.
    set_random_seed(seed)  # Sets the random number generator.  Using different values produces different results.
    for i in range(width):
        for j in range(height):
            # Uses the append method to add the next square.
            # This is a feature of object-oriented programming.
            squares.append(plot(polygon2d([(i,j),(i+1,j),(i+1,j+1),(i,j+1)], rgbcolor=RandomColor(color, delta))))
    # Python uses the "+" to mean many differnet things.  You can "add" graphics objects using "sum" and output them all together.
    P = plot(sum(squares), aspect_ratio=1, svg=True, axes=False, xmin=-1, xmax=width+1, ymin=-1, ymax=height+1)
    show(P)
    # This shows you how you would save your image to a file.
    save(P, 'colorsquare.svg')
︡0a47b63d-2eed-4617-852b-a862c3c2fbd4︡
︠5f7bd21d-dbbe-4f56-b16e-9e6ddda589db︠
ColorSquare(10, 10, [0.0,0.2,0.9], 0.1, 47)
︡c05e134a-4d96-4a30-97a6-a54d3bd191dc︡{"once":false,"file":{"show":true,"uuid":"b665cefd-619b-4f09-a894-0d9f7518c303","filename":"/projects/48a4f88a-5167-45ae-a54c-f4c735940fa0/.sage/temp/compute3-us/27197/tmp_bmp0YV.svg"}}︡{"html":"<div align='center'></div>"}︡
︠b3c43b62-2235-4a23-a62b-ebdfd8a4eefc︠
def RandomGray(gray, delta):
    change = delta * random ();
    return rgbcolor([gray + change, gray + change, gray + change]);

# As arguments, provide the width, height, level of gray, base radius for circles, 
# change in radius, change in gray, and the random number seed.
def TextureSquare(width, height, gray, r, rdelta, cdelta, seed):
    disks = []  # Saves the points in the final image.
    set_random_seed(seed)  # Sets the random number generator.  Using different values produces different results.
    for i in range(width):
        for j in range(height):
            disks.append(plot(disk((i,j), r + rdelta * random(), (0,2*pi), rgbcolor=RandomGray(gray, cdelta))))
    P = plot(sum(disks), aspect_ratio=1, svg=True, axes=False, xmin=-1, xmax=width+1, ymin=-1, ymax=height+1)
    show(P)
︡88b924ed-8374-4d80-b0ed-d6746b45fa36︡
︠4d68890e-bbe0-4ba2-a715-719611c34f8d︠
# Example just changing the radii of the circles.
# Just make the delta 0 (sixth argument to the function) so there is no change in color.
# Note that the gray is defined by a number between 0 (black) and 1 (white).
TextureSquare(20, 20, 0.3 ,0.4, 0.1, 0, 42)
︡2ffe80bf-5c8a-45ba-8db0-67c351869574︡{"once":false,"file":{"show":true,"uuid":"dd76dce5-32ed-4715-babf-bbf3b8af216b","filename":"/projects/48a4f88a-5167-45ae-a54c-f4c735940fa0/.sage/temp/compute3-us/11030/tmp_mTgxB_.svg"}}︡{"html":"<div align='center'></div>"}︡
︠46893790-992c-427e-b745-286fb9aa05ca︠
# Example just changing the color of the circles.
# Just make the rdelta 0 (fifth argument to the function) so there is no change in radius.
TextureSquare(20, 20, 0.3 ,0.45, 0, 0.3, 42)
︡4f8c4531-9e38-4cc8-9c29-18495d6dce33︡{"once":false,"file":{"show":true,"uuid":"0852eab2-d2af-4a8c-8c43-f87fb59d39d4","filename":"/projects/48a4f88a-5167-45ae-a54c-f4c735940fa0/.sage/temp/compute3-us/11030/tmp_B2dthl.svg"}}︡{"html":"<div align='center'></div>"}︡
︠475f4f75-5648-4db6-9b90-1ed6945d7b13︠
# Example changing both the radius and the color of the circles.
TextureSquare(20, 20, 0.3 ,0.4, 0.1, 0.3, 42)
︡58137916-1906-4964-a713-3dfef6f72b83︡{"once":false,"file":{"show":true,"uuid":"e4ab34ee-3e8d-493c-b2c1-96ce30054285","filename":"/projects/48a4f88a-5167-45ae-a54c-f4c735940fa0/.sage/temp/compute3-us/11030/tmp_ne0MMp.svg"}}︡{"html":"<div align='center'></div>"}︡
︠ca80e0f2-624d-4bdd-9d78-4652ee1e45c5︠









